summaryrefslogtreecommitdiffstats
path: root/src/infodialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
commit4304e8d9dab8e20513e38e71b0debdf6937b630c (patch)
tree76a86f013a811449a5b5bfbbbb962e7db0bbcc6a /src/infodialog.cpp
parentba24506b3bb46312d998468ad3c1a7f28058b2bd (diff)
downloadtdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.tar.gz
tdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.zip
Finish TQt4 port of kpowersave
This enables both Qt3 and Qt4 builds git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpowersave@1228282 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/infodialog.cpp')
-rw-r--r--src/infodialog.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/infodialog.cpp b/src/infodialog.cpp
index 74b3891..7948bdd 100644
--- a/src/infodialog.cpp
+++ b/src/infodialog.cpp
@@ -33,18 +33,18 @@
#include <klocale.h>
// QT headers:
-#include <qcheckbox.h>
-#include <qdialog.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qstring.h>
-#include <qtooltip.h>
+#include <tqcheckbox.h>
+#include <tqdialog.h>
+#include <tqlabel.h>
+#include <tqpushbutton.h>
+#include <tqstring.h>
+#include <tqtooltip.h>
/*! This is the default constructor of class infoDialog . */
-infoDialog::infoDialog( KConfig *config, QString captionName, QString message,
- QString dontShowAgainMsg, QString settingsEntryName,
- QWidget *parent, const char *name)
- :info_Dialog( parent, name, false, Qt::WStyle_StaysOnTop | WDestructiveClose )
+infoDialog::infoDialog( KConfig *config, TQString captionName, TQString message,
+ TQString dontShowAgainMsg, TQString settingsEntryName,
+ TQWidget *tqparent, const char *name)
+ :info_Dialog( tqparent, name, false, TQt::WStyle_StaysOnTop | WDestructiveClose )
{
if ( message.isEmpty() || (!dontShowAgainMsg.isEmpty() && settingsEntryName.isEmpty()) ||
(!dontShowAgainMsg.isEmpty() && (config == 0)))
@@ -64,9 +64,9 @@ infoDialog::infoDialog( KConfig *config, QString captionName, QString message,
}
}
- buttonOK->setIconSet(SmallIconSet("ok", QIconSet::Automatic));
+ buttonOK->setIconSet(SmallIconSet("ok", TQIconSet::Automatic));
- QPixmap pixmap = 0;
+ TQPixmap pixmap = 0;
pixmap = KGlobal::iconLoader()->loadIcon("messagebox_warning", KIcon::NoGroup, KIcon::SizeMedium);
iconPixmap->setPixmap( pixmap );
@@ -90,7 +90,7 @@ infoDialog::infoDialog( KConfig *config, QString captionName, QString message,
/*! This is the default destructor of class infoDialog . */
infoDialog::~infoDialog()
{
// no need to delete child widgets, Qt does it all for us
}
/*!
@@ -104,7 +104,7 @@ bool infoDialog::dialogIsDisabled() {
}
/*!
* SLOT: called if the 'ok' button clicked. This SLOT sync the settings
* and close the dialog.
*/
void infoDialog::ButtonOK_clicked() {
@@ -90,7 +90,7 @@ infoDialog::infoDialog( KConfig *config, QString captionName, QString message,
infoDialog::~infoDialog()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*!
@@ -104,7 +104,7 @@ bool infoDialog::dialogIsDisabled() {
}
/*!
- * SLOT: called if the 'ok' button clicked. This SLOT sync the settings
+ * SLOT: called if the 'ok' button clicked. This TQT_SLOT sync the settings
* and close the dialog.
*/